@@ -35,18 +35,16 @@ info_dict = {
         'type':list(),
 }
 
-metrics = get_keywords_metrics(email, api_key, df_create, match_extract)
-
-df_beta = df.copy()
+df_beta = get_keywords_metrics(email, api_key, df_create, match_extract)
 
 values = ['volume', 'cpc_exact', 'cpc_phrase']
-df_beta[values] = df_beta[values].apply(lambda x: x / 30)
+df_beta.loc[:,values] = df_beta.loc[:,values] / 30
 df_beta['total_cost'] = 0.33 * df_beta['volume'] * (( df_beta['cpc_exact'] + df_beta['cpc_phrase']) / 2) 
 df_beta['total_cost'] = df_beta['total_cost'].cumsum()
 df_beta = df_beta.sort_values(by=['total_cost'], na_position='last')
 df_beta = df_beta[df_beta['total_cost'] <= budget].reset_index(drop=True)
 
-spendings = df_beta['total_cost'].iloc[-1]
+# spendings = df_beta['total_cost'].iloc[-1]
 
 if len(df_expand) != 0:
     #code for expanding existing campaign
@@ -81,42 +79,42 @@ else:
 # code for ceating new campaign
 if len(df_create) != 0:
     try:
-        if spendings < budget:
-            print('Creatinng Beta Campaigns')
-            seed_keywords = df.groupby(['Keywords2']).groups
-            for k, d in seed_keywords.items():
-                campaign = create_campaign(googleads_client, customer_id, campaignName=f'beta_{k}',
-                                        budgetName=k+'_budget_'+f"{uuid.uuid4()}", budgetDollars=budget)
-                campaign_id = campaign.split('/')[-1]
-                data = df.iloc[d]['Keywords'].tolist()
-                for keyword in data:
-                    ad_group = create_adgroup(
-                        googleads_client, customer_id, campaign_id, adgroupName=keyword)
-                    if ad_group is None:
-                        continue
-                    ad_group_id = ad_group.split('/')[-1]
-                    keyword_id1 = create_keyword(
-                        googleads_client, customer_id,
-                        ad_group_id, keyword, kw_type='BROAD')
-                    keyword_id1 = keyword_id1.split('/')[-1]
-                    info_dict['campaign_id'].append(campaign_id)
-                    info_dict['adgroup_id'].append(ad_group_id)
-                    info_dict['keyword_id'].append(keyword_id1)
-                    info_dict['keyword_id2'].append(' ')
-                    info_dict['type'].append('created_beta')
-            info_df = pd.DataFrame.from_dict(info_dict)
-            df = pd.concat([df, info_df], axis=1)
-            df.to_csv(save_path+'/beta_info.csv', index=False)
-            print(f"{len(seed_keywords)} new campaigns created")
+#         if spendings < budget:
+#             print('Creatinng Beta Campaigns')
+#             seed_keywords = df.groupby(['Keywords2']).groups
+#             for k, d in seed_keywords.items():
+#                 campaign = create_campaign(googleads_client, customer_id, campaignName=f'beta_{k}',
+#                                         budgetName=k+'_budget_'+f"{uuid.uuid4()}", budgetDollars=budget)
+#                 campaign_id = campaign.split('/')[-1]
+#                 data = df.iloc[d]['Keywords'].tolist()
+#                 for keyword in data:
+#                     ad_group = create_adgroup(
+#                         googleads_client, customer_id, campaign_id, adgroupName=keyword)
+#                     if ad_group is None:
+#                         continue
+#                     ad_group_id = ad_group.split('/')[-1]
+#                     keyword_id1 = create_keyword(
+#                         googleads_client, customer_id,
+#                         ad_group_id, keyword, kw_type='BROAD')
+#                     keyword_id1 = keyword_id1.split('/')[-1]
+#                     info_dict['campaign_id'].append(campaign_id)
+#                     info_dict['adgroup_id'].append(ad_group_id)
+#                     info_dict['keyword_id'].append(keyword_id1)
+#                     info_dict['keyword_id2'].append(' ')
+#                     info_dict['type'].append('created_beta')
+#             info_df = pd.DataFrame.from_dict(info_dict)
+#             df = pd.concat([df, info_df], axis=1)
+#             df.to_csv(save_path+'/beta_info.csv', index=False)
+#             print(f"{len(seed_keywords)} new campaigns created")
         
-        else:
+#         else:
             print("Creating new Campaigns")
-            seed_keywords = df_create.groupby(['Keywords2']).groups  
+            seed_keywords = df_beta.groupby(['Keywords2']).groups  
             for k, d in seed_keywords.items():
                 campaign = create_campaign(googleads_client,customer_id,campaignName=k,
                                            budgetName=k+'_budget_'+f"{uuid.uuid4()}", budgetDollars=budget)
                 campaign_id = campaign.split('/')[-1]
-                data = df_create.iloc[d]['Keywords'].tolist()
+                data = df_beta.iloc[d]['Keywords'].tolist()
                 for keyword in data:
                     ad_group = create_adgroup(googleads_client,customer_id,campaign_id, adgroupName=keyword)
                     if ad_group is None:
